package org.herac.tuxguitar.app.view.dialog.keybindings;

import org.herac.tuxguitar.ui.resource.UIKeyConvination;

public interface TGKeyBindingSelectorHandler {
	
	void handleSelection(UIKeyConvination kb);
}
